import java.awt.Color;

/**
 * Schreibt einen Text auf die Leinwand.
 * 
 * @author Bernd Gramlich
 * @version 2015-07-01
 */
public class Beschriftung
{
    /*
     * Position des Referenzpunktes relativ zum Zentrum, und zwar
     * vor der Drehung.
     */
    private int positionX;
    private int positionY;

    /*
     * Art des Referenzpunkts fr die Y-Achse.
     * (0: Textmitte, 1: untere Textmitte, -1: obere Textmitte)
     */
    private int ausrichtungY;

    /*
     * Art des Referenzpunkts fr die X-Achse.
     * (0: Textmitte, 1: rechts der Textmitte, -1: limks der Textmitte)
     */
    private int ausrichtungX;

    /*
     * Der Text.
     */
    private String inhalt;

    /*
     * Die Richtung, in die der Text verlaeuft.
     * (Ein waagrechter Text entsteht bei drehX = 1 und drehY = 0,
     * ein senkrechter von unten nach oben bei drehX = 0 und
     * drehY = 1.)
     */
    private int drehX;
    private int drehY;

    /*
     * Das Zentrum, um das der Text gedreht wird.
     */
    private int zentrumX;
    private int zentrumY;

    /*
     * Farbe, Schriftgroesse und Sichtbarkeit.
     */
    private Color farbe;
    private int schriftgroesse;
    private boolean sichtbar;

    /**
     * Konstruktor der Klasse Beschriftung.
     * Erzeugt eine neue Beschriftung mit Standardtext in Standardgroesse und Standardfarbe.
     */
    public Beschriftung ()
    { 
        positionX      = 300;
        positionY      = 225;

        ausrichtungY    = 0;

        inhalt         = "Informatik macht Spass.";

        drehX          = 1;
        drehY          = 0;

        zentrumX       = 0;
        zentrumY       = 0;

        farbe          = Color.gray;
        schriftgroesse = 12;
        sichtbar       = false;
    }

    /**
     * Mache diesen Text sichtbar.
     */
    public void werdeSichtbar ()
    {
        sichtbar = true;
        schreibe ();
    }

    /**
     * Mache diesen Text unsichtbar.
     */
    public void werdeUnsichtbar ()
    {
        radiere ();
        sichtbar = false;
    }

    /**
     * Aendere die Drehrichtung des Textes.
     */
    public void setzeDrehrichtung (int dX, int dY)
    {
        drehX = dX;
        drehY = dY;
        schreibe ();
    }

    /**
     * Aendere das Drehzentrum des Textes.
     */
    public void setzeDrehzentrum (int zX, int zY)
    {
        zentrumX = zX;
        zentrumY = zY;
        schreibe ();
    }

    /**
     * Aendere die Farbe dieses Textes in 'neueFarbe'.
     */
    public void setzeFarbe (Color neueFarbe)
    {
        farbe = neueFarbe;
        schreibe ();
    }

    /**
     * Aendere die Position dieses Textes.
     * Es handelt sich um die Position des Referenzpunkts des
     * Textes relativ zum Zentrum, und zwar vor der Drehung.
     */
    public void setzePosition (int neuePositionX, int neuePositionY)
    {
        positionX = neuePositionX;
        positionY = neuePositionY;
        schreibe ();
    }

    /**
     * Aendere die Art des Referenzpunkts.
     * (0: Textmitte, 1: untere Textmitte, -1: obere Textmitte)
     */
    public void setzeAusrichtungY (int neueAusrichtungY)
    {
        ausrichtungY = 0;

        if (neueAusrichtungY > 0)
        {
            ausrichtungY = 1;
        }
        else if (neueAusrichtungY < 0)
        {
            ausrichtungY = -1;
        }
        schreibe ();
    }

    /**
     * Aendere die Art des Referenzpunkts.
     * (0: Textmitte, 1: rechts der Textmitte, -1: links der Textmitte)
     */
    public void setzeAusrichtungX (int neueAusrichtungX)
    {
        ausrichtungX = 0;

        if (neueAusrichtungX > 0)
        {
            ausrichtungX = 1;
        }
        else if (neueAusrichtungX < 0)
        {
            ausrichtungX = -1;
        }
        schreibe ();
    }

    /**
     * Aendere die Schriftgroesse dieses Textes.
     */
    public void setzeSchriftgroesse (int neueSchriftgroesse)
    {
        schriftgroesse = neueSchriftgroesse;
        schreibe ();
    }

    /**
     * Aendere den Inhalt dieses Textes.
     */
    public void setzeInhalt (String neuerInhalt)
    {
        inhalt = neuerInhalt;
        schreibe ();
    }

    /**
     * Schreibe diesen Text auf die Leinwand.
     */
    private void schreibe ()
    {
        if (sichtbar)
        {
            Leinwand leinwand = Leinwand.gibLeinwand ();
            leinwand.merkeZumSchreibenVor (this, farbe, inhalt, positionX, positionY, drehX, drehY, zentrumX, zentrumY, ausrichtungY, ausrichtungX, schriftgroesse);
        }
    }

    /**
     * Loesche diesen Text von der Leinwand.
     */
    private void radiere ()
    {
        if (sichtbar)
        {
            Leinwand leinwand = Leinwand.gibLeinwand ();
            leinwand.merkeZumRadierenVor (this);
        }
    }

    /**
     * Nenne den Text dieser Beschriftung.
     */
    public String gibText ()
    {
        return inhalt;
    }
}